@@ -1,5 +1,5 @@
 /***************************************************************************
-    Copyright 2008-2010 Daniel Laidig <d.laidig@gmx.de>
+    Copyright 2014 Inge Wallin <inge@lysator.liu.se>
  ***************************************************************************/
 
 /***************************************************************************
@@ -11,6 +11,18 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <Qt>
+#include <QtGui>
+#include <QTimer>
+#include <QAction>
+#include <QMessageBox>
+#include <QDebug>
+#include <QSignalMapper>
+#include <QStandardItemModel>
+
+//#include <KMimeType>
+#include <KActionCollection>
+
 #include "dashboard.h"
 #include "buttondelegate.h"
 #include "parleymainwindow.h"
@@ -19,27 +31,13 @@
 #include "practice/imagewidget.h"
 #include "statistics/statisticsmainwindow.h"
 #include "statistics/statisticsmodel.h"
-#include <QSignalMapper>
-#include <KLocalizedString>
-
-#include <QGraphicsDropShadowEffect>
-#include <QStandardItemModel>
-#include <QTimer>
-#include <QAction>
-#include <QMessageBox>
-#include <QDebug>
-
-#include <QtGui>
-#include <Qt>
-
-//#include <KMimeType>
-#include <KActionCollection>
 
 #include "collection.h"
 #include "collectionwidget.h"
 #include "barwidget.h"
 #include "gradereferencewidget.h"
 
+
 // ----------------------------------------------------------------
 
 static int randInt(int low, int high)
