@@ -20,9 +20,6 @@
 // Qt
 #include <QVector>
 
-// kdelibs
-#include <KRandomSequence>
-
 // kdeedulibs
 #include <keduvocexpression.h>
 
@@ -172,8 +169,6 @@ protected:  // data
     QTime m_time;
     int m_totalTime;
 
-    KRandomSequence m_randomSequence;
-
     friend class EntryFilter;
 };
 
